@@ -3,33 +3,45 @@ import os
 import pandas as pd
 import numpy as np
 import requests
+import webbrowser
 from .dataframe_tools import slugify as slugify_func
 from typing import List, Optional
 
 
 class SFDCEnv:
-    try:
-        USERNAME = os.environ['SALESFORCE_USERNAME']
-        PASSWORD = os.environ['SALESFORCE_PASSWORD']
-        TOKEN = os.environ['SALESFORCE_SECURITY_TOKEN']
-    except KeyError:
-        raise KeyError(
-            (
-                'Can\'t find salesforce environment variables.  Required variables are\n'
-                'SALESFORCE_USERNAME\n'
-                'SALESFORCE_PASSWORD\n'
-                'SALESFORCE_SECURITY_TOKEN\n'
+    def __init__(self):
+        try:
+            self.USERNAME = os.environ['SALESFORCE_USERNAME']
+            self.PASSWORD = os.environ['SALESFORCE_PASSWORD']
+            self.TOKEN = os.environ['SALESFORCE_SECURITY_TOKEN']
+        except KeyError:
+            raise KeyError(
+                (
+                    'Can\'t find salesforce environment variables.  Required variables are\n'
+                    'SALESFORCE_USERNAME\n'
+                    'SALESFORCE_PASSWORD\n'
+                    'SALESFORCE_SECURITY_TOKEN\n'
+                )
             )
-        )
 
 
 class SalesForceReport(SFDCEnv):
 
     def __init__(self):
+        super().__init__()
+
         # Import here to avoid simple_salesforce dependency at ezr import
         import simple_salesforce
+        self.session = requests.Session()
         self.sf_obj = simple_salesforce.Salesforce(
-            username=self.USERNAME, password=self.PASSWORD, security_token=self.TOKEN)
+            username=self.USERNAME, password=self.PASSWORD, security_token=self.TOKEN, session=self.session)
+
+    def __del__(self):
+        self.session.close()
+
+    @classmethod
+    def open_report(cls, report_id):
+        webbrowser.open_new(f'https://ambition.lightning.force.com/lightning/r/Report/{report_id}/view')
 
     def get_report(
             self,
@@ -39,14 +51,14 @@ class SalesForceReport(SFDCEnv):
             remove_copyright: bool = True
     ):
         url = f'https://{self.sf_obj.sf_instance}/{report_id}'
-        self.req = requests.get(
-            url,
-            params=dict(export=1, xf='csv', enc='UTF-8', isdtp='p1'),
-            cookies=dict(sid=self.sf_obj.session_id)
-        )
-        df = pd.read_csv(io.BytesIO(self.req.content))
-        if slugify:
-            df.columns = slugify_func(df.columns)
+        with requests.get(
+                url,
+                params=dict(export=1, xf='csv', enc='UTF-8', isdtp='p1'),
+                cookies=dict(sid=self.sf_obj.session_id)
+        ) as req:
+            df = pd.read_csv(io.BytesIO(req.content))
+            if slugify:
+                df.columns = slugify_func(df.columns)
 
         if date_fields:
             for field in date_fields:
